#
# Copyright (C) 2014 Conjur Inc
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of
# this software and associated documentation files (the "Software"), to deal in
# the Software without restriction, including without limitation the rights to
# use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
# the Software, and to permit persons to whom the Software is furnished to do so,
# subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
# FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
# COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
# IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#

require 'conjur/trial'

module Conjur
  class API
    # List all trials
    def trials
      JSON.parse(trial_factory_resource.get).map do |resp|
        build_trial resp
      end
    end
    
    # Show a specific trial
    def trial account, options = {}
      resource = trial_factory_resource(account)
      build_trial resource.get(params: options)
    end
    
    # Creates a new trial
    def create_trial account, email, options = {}
      resp = trial_factory_resource.post({
        account: account,
        email: email
      }.merge(options.slice(:imageid)))
      build_trial resp
    end
    
    protected
    
    def build_trial resp
      resp = JSON.parse(resp) if resp.is_a?(String)
      Trial.new(trial_factory_path(resp['account']), credentials).tap do |trial|
        trial.attributes = resp
      end
    end
    
    def trial_factory_resource *path
      RestClient::Resource.new(Conjur::API.trial_factory_asset_host, credentials)[trial_factory_path *path]
    end
    
    def trial_factory_path *args
      args.map{|a| fully_escape(a)}.join('/')
    end
  end
end
