#
# Copyright (C) 2014 Conjur Inc
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of
# this software and associated documentation files (the "Software"), to deal in
# the Software without restriction, including without limitation the rights to
# use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
# the Software, and to permit persons to whom the Software is furnished to do so,
# subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
# FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
# COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
# IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#

require 'conjur/trial-factory-api'

class Conjur::Command::TrialFactories < Conjur::Command
  desc "Manage trials"
  command :trial do |trials|
    trials.desc 'Create a new trial'
    trials.arg_name 'account email'
    trials.command "create" do |c|
      c.desc "Override the image id"
      c.flag [:i, :imageid]
        
      c.action do |global_options,options,args|
        account = require_arg(args, 'account')
        email = require_arg(args, 'email')
        
        trial = api.create_trial account, email, options.slice(:imageid)
        display trial
      end
    end

    trials.desc 'List trials'
    trials.command "list" do |c|
      c.action do |global_options,options,args|
        trials = api.trials.map { |t| t.attributes }
        puts JSON.pretty_generate(trials)
      end
    end
    
    trials.desc 'Show trials which are at least 30 days old, and have no activity'
    trials.command "stale" do |c|
      c.action do |global_options,options,args|
        require 'time'
        ago = Time.now - 30.days
        trials = api.trials
        found = 0
        puts "[\n"
        trials.each do |t|
          account = t.attributes['account']
          contact = t.attributes['contact']
          info = api.trial(account, short: true)
          launch_time = Time.parse(info.attributes['instance']['launch_time'])
          if launch_time < ago && info.attributes['activity']['count'] == 0
            if found != 0
              $stdout.write ",\n"
            end
            $stdout.write "  "
            $stdout.write JSON.generate([ account, contact ])
            found += 1
          end
        end
        puts "\n]"
      end
    end
    
    trials.desc 'Show details of a trial appliance, including recent usage'
    trials.arg_name 'account'
    trials.command "show" do |c|
      c.desc "Abbreviated output"
      c.switch [:s, :short]
      
      c.action do |global_options,options,args|
        account = require_arg(args, 'account')
        
        display api.trial(account, options.slice(:short))
      end
    end
  end
end
